// src/hasura.ts
import { requestLogger } from "@settlemint/sdk-utils/logging";
import { ensureServer } from "@settlemint/sdk-utils/runtime";
import { ApplicationAccessTokenSchema, UrlOrPathSchema, validate } from "@settlemint/sdk-utils/validation";
import { initGraphQLTada } from "gql.tada";
import { GraphQLClient } from "graphql-request";
import { z } from "zod";
import { readFragment } from "gql.tada";
var ClientOptionsSchema = z.object({
  instance: UrlOrPathSchema,
  accessToken: ApplicationAccessTokenSchema,
  adminSecret: z.string(),
  cache: z.enum(["default", "force-cache", "no-cache", "no-store", "only-if-cached", "reload"]).optional()
});
function createHasuraClient(options, clientOptions, logger) {
  ensureServer();
  const validatedOptions = validate(ClientOptionsSchema, options);
  const graphql = initGraphQLTada();
  const fullUrl = new URL(validatedOptions.instance).toString();
  return {
    client: new GraphQLClient(fullUrl, {
      ...clientOptions,
      headers: {
        ...clientOptions?.headers ?? {},
        "x-auth-token": validatedOptions.accessToken,
        "x-hasura-admin-secret": validatedOptions.adminSecret
      },
      fetch: logger ? requestLogger(logger, "hasura", fetch) : fetch
    }),
    graphql
  };
}
export {
  ClientOptionsSchema,
  createHasuraClient,
  readFragment
};
//# sourceMappingURL=hasura.mjs.map